@@ -1,6 +1,6 @@
 package Proc::tored::Manager;
 # ABSTRACT: OO interface to creating a proctored service
-$Proc::tored::Manager::VERSION = '0.11';
+$Proc::tored::Manager::VERSION = '0.12';
 
 use strict;
 use warnings;
@@ -219,7 +219,13 @@ sub run_lock {
     $file->spew("$$\n");
 
     # Create guard object that releases the pidfile once out of scope
-    return guard { $file->remove if $self->is_running };
+    return guard {
+      if ($self->is_running) {
+        $file->append({truncate => 1});
+        try { $file->remove }
+        catch { warn "error unlinking $file: $_" }
+      }
+    };
   }
 
   return;
@@ -275,7 +281,7 @@ Proc::tored::Manager - OO interface to creating a proctored service
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
